%%
%%--------------------------------------------------------------------

-module(database_forward).

%%--------------------------------------------------------------------
%% External exports
%%--------------------------------------------------------------------
-export([
	 create/0,
	 create/1,
	 insert/4,
	 fetch/1,
	 list/0,
	 delete/1
	]).

%%--------------------------------------------------------------------
%% Internal exports
%%--------------------------------------------------------------------

%%--------------------------------------------------------------------
%% Include files
%%--------------------------------------------------------------------

-include("database_forward.hrl").

%%--------------------------------------------------------------------
%% Records
%%--------------------------------------------------------------------

%%--------------------------------------------------------------------
%% Macros
%%--------------------------------------------------------------------

%%====================================================================
%% External functions
%%====================================================================



%%--------------------------------------------------------------------
%% Function:
%% Descrip.:
%% Returns :
%%--------------------------------------------------------------------
create() ->
    create([node()]).

create(Servers) ->
    mnesia:create_table(forward, [{attributes, record_info(fields, forward)},
				  {disc_copies, Servers}
				  %% key = number
				  %% type = set, default for table
				 ]).

%%--------------------------------------------------------------------
%% Function:
%% Descrip.:
%% Returns :
%%--------------------------------------------------------------------
insert(Number, Forwards, Timeout, Localring) ->
    db_util:insert_record(#forward{number = Number,
			   forwards = Forwards,
			   timeout = Timeout,
			   localring = Localring}).

%%--------------------------------------------------------------------
%% Function:
%% Descrip.:
%% Returns : list() of forward record()
%%--------------------------------------------------------------------
list() ->
    db_util:tab_to_list(forward).

%%--------------------------------------------------------------------
%% Function:
%% Descrip.:
%% Returns : {Forwards, Timeout, LocalRing}
%%--------------------------------------------------------------------
fetch(Number) ->
	F = fun() ->
		    MatchSpec = [{#forward{number = Number, _ = '_'},
				  [],
				  [{{{element, #forward.forwards, '$_'},
				     {element, #forward.timeout, '$_'},
				     {element, #forward.localring, '$_'}
				    }}]
				 }],
		    mnesia:select(forward, MatchSpec)
	    end,
    mnesia:transaction(F).

%%--------------------------------------------------------------------
%% Function:
%% Descrip.:
%% Returns :
%%--------------------------------------------------------------------
delete(Number) ->
    db_util:delete_with_key(forward, Number).


%%====================================================================
%% Behaviour functions
%%====================================================================

%%====================================================================
%% Internal functions
%%====================================================================



